==> transmedika_one_to_one_call-1.0.22.tar.gz: lib/webrtc/constants.dart <==
class Constants{
  static const String register = 'register';
  static const String stop = 'stop';
  static const String call = 'call';
  static const String joinRoom = 'joinRoom';
  static const String receiveVideoFrom = 'receiveVideoFrom';
  static const String leaveRoom = 'leaveRoom';
  static const String notifyCaller = 'notifyCaller';
  static const String rejectCalling = 'rejectCalling';
  static const String calling = 'calling';
  static const String notifyCallerActive = 'notifyCallerActive';
  static const String notifyCallerNotActive = 'notifyCallerNotActive';
  static const String onIceCandidate = 'onIceCandidate';
  static const String incomingCallResponse = 'incomingCallResponse';
  static const String registerResponse = 'registerResponse';
  static const String presenterResponse = 'presenterResponse';
  static const String iceCandidate = 'iceCandidate';
  static const String viewerResponse = 'viewerResponse';
  static const String stopCommunication = 'stopCommunication';
  static const String closeRoomResponse = 'closeRoomResponse';
  static const String incomingCall = 'incomingCall';
  static const String startCommunication = 'startCommunication';
  static const String callResponse = 'callResponse';
  static const String callingResponse = 'callingResponse';
  static const String existingParticipants = 'existingParticipants';
  static const String newParticipantArrived = 'newParticipantArrived';
  static const String participantLeft = 'participantLeft';
  static const String receiveVideoAnswer = 'receiveVideoAnswer';
  static const String unknown = 'unknown';

  static const String accept = 'accept';
  static const String accepted = 'accepted';
  static const String rejected = 'rejected';

  /// local media constraint webrtc ///
  static const Map<String, dynamic> mediaConstraints = {
    'audio': true,
    'video': {
      'mandatory': {
        'minWidth': '320',
        'minHeight': '240',
        'minFrameRate': '30',
      },
      'facingMode': 'user',
      'optional': [],
    }
  };

  /// transmedika ice servers ///
  static const iceServers = {
    'iceServers': [
      {
        'url': 'turn:167.71.204.0:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:159.65.9.21:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:159.89.202.60:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:174.138.20.143:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:139.59.99.228:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:174.138.30.241:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
    ]
  };

  /// web rtc constraint ///
  static const constraints = {
    'mandatory': {
      'OfferToReceiveAudio': true,
      'OfferToReceiveVideo': true,
    },
    'optional': [
      {'DtlsSrtpKeyAgreement': true},
    ],
  };

  static const planB = 'plan-b';
  static const unifiedPlan = 'unified-plan';

  static const sdpSemantics = unifiedPlan;

  /// webrtc configuration ///
  static const rtcConfig = {
    'tcpCandidatePolicy': 'enabled',
    'keyType': 'ECDSA',
    'sdpSemantics': sdpSemantics,
    'bundlePolicy': 'max-bundle',
    'rtcpMuxPolicy': 'negotiate',
    'continualGatheringPolicy':'gather_continually'
  };


}

==> transmedika_one_to_one_call-1.0.33.tar.gz: lib/webrtc/constants.dart <==
class Constants{
  static const String register = 'register';
  static const String stop = 'stop';
  static const String call = 'call';
  static const String joinRoom = 'joinRoom';
  static const String receiveVideoFrom = 'receiveVideoFrom';
  static const String leaveRoom = 'leaveRoom';
  static const String notifyCaller = 'notifyCaller';
  static const String rejectCalling = 'rejectCalling';
  static const String calling = 'calling';
  static const String notifyCallerActive = 'notifyCallerActive';
  static const String notifyCallerNotActive = 'notifyCallerNotActive';
  static const String onIceCandidate = 'onIceCandidate';
  static const String incomingCallResponse = 'incomingCallResponse';
  static const String registerResponse = 'registerResponse';
  static const String presenterResponse = 'presenterResponse';
  static const String iceCandidate = 'iceCandidate';
  static const String viewerResponse = 'viewerResponse';
  static const String stopCommunication = 'stopCommunication';
  static const String closeRoomResponse = 'closeRoomResponse';
  static const String incomingCall = 'incomingCall';
  static const String startCommunication = 'startCommunication';
  static const String callResponse = 'callResponse';
  static const String callingResponse = 'callingResponse';
  static const String existingParticipants = 'existingParticipants';
  static const String newParticipantArrived = 'newParticipantArrived';
  static const String participantLeft = 'participantLeft';
  static const String receiveVideoAnswer = 'receiveVideoAnswer';
  static const String unknown = 'unknown';

  static const String accept = 'accept';
  static const String accepted = 'accepted';
  static const String rejected = 'rejected';

  /// transmedika ice servers ///
  static const iceServers = {
    'iceServers': [
      {
        'url': 'turn:167.71.204.0:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:159.65.9.21:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:159.89.202.60:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:174.138.20.143:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:139.59.99.228:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
      {
        'url': 'turn:174.138.30.241:3478',
        'username': 'netkrom',
        'credential': 'bull3tX',
      },
    ]
  };

  /// web rtc constraint ///
  static const sdpConstraint = {
    'mandatory': {
      'OfferToReceiveAudio': true,
      'OfferToReceiveVideo': true,
    },
    'optional': [],
  };

  /// loop back constraint
  static const loopbackConstraints = <String, dynamic>{
    'mandatory': {},
    'optional': [
      {'DtlsSrtpKeyAgreement': false},
    ],
  };

  static const planB = 'plan-b';
  static const unifiedPlan = 'unified-plan';

  static const sdpSemantics = unifiedPlan;

  /// webrtc configuration ///
  static const rtcConfig = {
    'tcpCandidatePolicy': 'enabled',
    'keyType': 'ECDSA',
    'sdpSemantics': sdpSemantics,
    'bundlePolicy': 'max-bundle',
    'rtcpMuxPolicy': 'negotiate',
    'continualGatheringPolicy':'gather_continually'
  };


}
